@@ -4,7 +4,7 @@
 library(pbdDEMO, quietly = TRUE)
 init.grid()
 if(comm.size() != 4){
-  stop("This example requries 4 processors.")
+  comm.stop("This example requries 4 processors.")
 }
 comm.set.seed(1234, diff = TRUE)
 
