@@ -4,12 +4,10 @@
 library(pbdDEMO, quietly = TRUE)
 init.grid()
 if(comm.size() != 4){
-  stop("This example requries 4 processors.")
+  comm.stop("This example requries 4 processors.")
 }
 
 
-init.grid()
-
 n <- 1250
 p <- 40
 
